==> pierogi_0.6.4.tar.gz: pierogi-0.6.4/keysets/aiwa.h <==
#ifndef AIWA_H
#define AIWA_H

#include "pirkeysetmetadata.h"

class QObject;

class AiwaVCR1: public PIRKeysetMetaData
{
public:
  AiwaVCR1(
    QObject *guiObject,
    unsigned int index);
};

class AiwaVCR2: public PIRKeysetMetaData
{
public:
  AiwaVCR2(
    QObject *guiObject,
    unsigned int index);
};

class AiwaVCR3: public PIRKeysetMetaData
{
public:
  AiwaVCR3(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio1: public PIRKeysetMetaData
{
public:
  AiwaAudio1(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio1a: public AiwaAudio1
{
public:
  AiwaAudio1a(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio2: public PIRKeysetMetaData
{
public:
  AiwaAudio2(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio2a: public AiwaAudio2
{
public:
  AiwaAudio2a(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio2b: public AiwaAudio2
{
public:
  AiwaAudio2b(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio2c: public AiwaAudio2
{
public:
  AiwaAudio2c(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio3: public PIRKeysetMetaData
{
public:
  AiwaAudio3(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio4: public PIRKeysetMetaData
{
public:
  AiwaAudio4(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio5: public PIRKeysetMetaData
{
public:
  AiwaAudio5(
    QObject *guiObject,
    unsigned int index);
};

class AiwaAudio6: public PIRKeysetMetaData
{
public:
  AiwaAudio6(
    QObject *guiObject,
    unsigned int index);
};

class AiwaCarStereo1: public PIRKeysetMetaData
{
public:
  AiwaCarStereo1(
    QObject *guiObject,
    unsigned int index);
};

class AiwaDVD1: public PIRKeysetMetaData
{
public:
  AiwaDVD1(
    QObject *guiObject,
    unsigned int index);
};

#endif // AIWA_H

==> pierogi_1.1.3.tar.gz: pierogi-1.1.3/keysets/aiwa.h <==
#ifndef AIWA_H
#define AIWA_H

#include "pirkeysetmetadata.h"

class QObject;

class AiwaVCR1: public PIRKeysetMetaData
{
public:
  AiwaVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaVCR2: public PIRKeysetMetaData
{
public:
  AiwaVCR2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaVCR3: public PIRKeysetMetaData
{
public:
  AiwaVCR3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio1: public PIRKeysetMetaData
{
public:
  AiwaAudio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio1a: public AiwaAudio1
{
public:
  AiwaAudio1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio2: public PIRKeysetMetaData
{
public:
  AiwaAudio2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio2a: public AiwaAudio2
{
public:
  AiwaAudio2a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio2b: public AiwaAudio2
{
public:
  AiwaAudio2b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio2c: public AiwaAudio2
{
public:
  AiwaAudio2c(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio3: public PIRKeysetMetaData
{
public:
  AiwaAudio3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio4: public PIRKeysetMetaData
{
public:
  AiwaAudio4(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio5: public PIRKeysetMetaData
{
public:
  AiwaAudio5(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaAudio6: public PIRKeysetMetaData
{
public:
  AiwaAudio6(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaCarStereo1: public PIRKeysetMetaData
{
public:
  AiwaCarStereo1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class AiwaDVD1: public PIRKeysetMetaData
{
public:
  AiwaDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // AIWA_H
